package com.ruoyi.tcZz.mapper;

import java.util.List;
import com.ruoyi.tcZz.domain.TcZdgzxm;
import org.apache.ibatis.annotations.Param;

/**
 * 重点工作项目Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
public interface TcZdgzxmMapper 
{
    /**
     * 查询重点工作项目
     * 
     * @param id 重点工作项目主键
     * @return 重点工作项目
     */
    public TcZdgzxm selectTcZdgzxmById(Long id);

    /**
     * 查询重点工作项目列表
     * 
     * @param tcZdgzxm 重点工作项目
     * @return 重点工作项目集合
     */
    public List<TcZdgzxm> selectTcZdgzxmList(TcZdgzxm tcZdgzxm);

    /**
     * 新增重点工作项目
     * 
     * @param tcZdgzxm 重点工作项目
     * @return 结果
     */
    public int insertTcZdgzxm(TcZdgzxm tcZdgzxm);

    /**
     * 修改重点工作项目
     * 
     * @param tcZdgzxm 重点工作项目
     * @return 结果
     */
    public int updateTcZdgzxm(TcZdgzxm tcZdgzxm);

    /**
     * 删除重点工作项目
     * 
     * @param id 重点工作项目主键
     * @return 结果
     */
    public int deleteTcZdgzxmById(Long id);

    /**
     * 批量删除重点工作项目
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcZdgzxmByIds(Long[] ids);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(@Param("isStatus") Integer isStatus, @Param("ids") List<String> ids);
}
