package com.ruoyi.tcZz.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.domain.TcZbxq;
import com.ruoyi.tcZz.domain.TcZdgzxm;
import com.ruoyi.tcZz.service.ITcZdgzxmService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 重点工作项目Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "重点工作项目")
@RequestMapping("/tcZz/netManage/zdgzxm")
public class TcZdgzxmController extends BaseController {
    @Autowired
    private ITcZdgzxmService tcZdgzxmService;

    /**
     * 查询重点工作项目列表
     */
    @ApiOperation(value = "查询重点工作项目列表", response = TcZdgzxm.class)
    @GetMapping("/list")
    public TableDataInfo list(TcZdgzxm tcZdgzxm) {
        startPage();
        List<TcZdgzxm> list = tcZdgzxmService.selectTcZdgzxmList(tcZdgzxm);
        return getDataTable(list);
    }

    /**
     * 导出重点工作项目列表
     */
    @ApiOperation(value = "导出重点工作项目列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcZdgzxm tcZdgzxm) {
        List<TcZdgzxm> list = tcZdgzxmService.selectTcZdgzxmList(tcZdgzxm);
        ExcelUtil<TcZdgzxm> util = new ExcelUtil<TcZdgzxm>(TcZdgzxm.class);
        util.exportExcel(response, list, "重点工作项目数据");
    }

    /**
     * 获取重点工作项目详细信息
     */
    @ApiOperation(value = "获取重点工作项目详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcZdgzxmService.selectTcZdgzxmById(id));
    }

    /**
     * 新增重点工作项目
     */
    @ApiOperation(value = "新增重点工作项目")
    @PostMapping
    public AjaxResult add(@RequestBody TcZdgzxm tcZdgzxm) {
        return toAjax(tcZdgzxmService.insertTcZdgzxm(tcZdgzxm));
    }

    /**
     * 修改重点工作项目
     */
    @ApiOperation(value = "修改重点工作项目")
    @PutMapping
    public AjaxResult edit(@RequestBody TcZdgzxm tcZdgzxm) {
        return toAjax(tcZdgzxmService.updateTcZdgzxm(tcZdgzxm));
    }

    /**
     * 删除重点工作项目
     */
    @ApiOperation(value = "删除重点工作项目")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcZdgzxmService.deleteTcZdgzxmByIds(ids));
    }



    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcZdgzxm> util = new ExcelUtil<TcZdgzxm>(TcZdgzxm.class);
        List<TcZdgzxm> tcZdgzxmList = util.importExcel(file.getInputStream());
        tcZdgzxmService.importUser(tcZdgzxmList);
        return AjaxResult.success();
    }
    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus,@RequestParam("ids") List<String> ids) {
        tcZdgzxmService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcZdgzxm> util = new ExcelUtil<TcZdgzxm>(TcZdgzxm.class);
        util.importTemplateExcel(response, " 重点工作项目");
    }
}
